"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub,
    ctx,
    application_name: str,
    current_application_version_id: int,
    reference_data_source: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.  Adds a reference data source to an existing application. Amazon Kinesis Analytics reads reference data (that is, an Amazon S3 object) and creates an in-application table within your application. In the request, you provide the source (S3 bucket name and object key name), name of the in-application table to create, and the necessary mapping information that describes how data in Amazon S3 object maps to columns in the resulting in-application table.  For conceptual information, see Configuring Application Input. For the limits on data sources you can add to your application, see Limits.   This operation requires permissions to perform the kinesisanalytics:AddApplicationOutput action.

    Args:
        application_name(str): Name of an existing application.
        current_application_version_id(int): Version of the application for which you are adding the reference data source. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ConcurrentModificationException is returned.
        reference_data_source(Dict): The reference data source can be an object in your Amazon S3 bucket. Amazon Kinesis Analytics reads the object and copies the data into the in-application table that is created. You provide an S3 bucket, object key name, and the resulting in-application table that is created. You must also provide an IAM role with the necessary permissions that Amazon Kinesis Analytics can assume to read the object from your S3 bucket on your behalf.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.application.reference_data_source.add(
                ctx,
                application_name=value,
                current_application_version_id=value,
                reference_data_source=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.application.reference_data_source.add application_name=value, current_application_version_id=value, reference_data_source=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="add_application_reference_data_source",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "ReferenceDataSource": reference_data_source,
        },
    )


async def delete(
    hub,
    ctx,
    application_name: str,
    current_application_version_id: int,
    reference_id: str,
) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.  Deletes a reference data source configuration from the specified application configuration. If the application is running, Amazon Kinesis Analytics immediately removes the in-application table that you created using the AddApplicationReferenceDataSource operation.  This operation requires permissions to perform the kinesisanalytics.DeleteApplicationReferenceDataSource action.

    Args:
        application_name(str): Name of an existing application.
        current_application_version_id(int): Version of the application. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ConcurrentModificationException is returned.
        reference_id(str): ID of the reference data source. When you add a reference data source to your application using the AddApplicationReferenceDataSource, Amazon Kinesis Analytics assigns an ID. You can use the DescribeApplication operation to get the reference ID. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.application.reference_data_source.delete(
                ctx,
                application_name=value,
                current_application_version_id=value,
                reference_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.application.reference_data_source.delete application_name=value, current_application_version_id=value, reference_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="delete_application_reference_data_source",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "ReferenceId": reference_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, ticket_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves one or more matchmaking tickets. Use this operation to retrieve ticket information, including--after a successful match is made--connection information for the resulting new game session.  To request matchmaking tickets, provide a list of up to 10 ticket IDs. If the request is successful, a ticket object is returned for each requested ID that currently exists. This operation is not designed to be continually called to track matchmaking ticket status. This practice can cause you to exceed your API limit, which results in errors. Instead, as a best practice, set up an Amazon Simple Notification Service (SNS) to receive notifications, and provide the topic ARN in the matchmaking configuration. Continuously poling ticket status with DescribeMatchmaking should only be used for games in development with low matchmaking usage.   Learn more    Add FlexMatch to a game client    Set Up FlexMatch event notification   Related actions   StartMatchmaking | DescribeMatchmaking | StopMatchmaking | AcceptMatch | StartMatchBackfill | All APIs by task

    Args:
        ticket_ids(List): A unique identifier for a matchmaking ticket. You can include up to 10 ID values. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.matchmaking.init.describe(ctx, ticket_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.matchmaking.init.describe ticket_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_matchmaking",
        op_kwargs={"TicketIds": ticket_ids},
    )


async def start(
    hub, ctx, configuration_name: str, players: List, ticket_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Uses FlexMatch to create a game match for a group of players based on custom matchmaking rules. With games that use GameLift managed hosting, this operation also triggers GameLift to find hosting resources and start a new game session for the new match. Each matchmaking request includes information on one or more players and specifies the FlexMatch matchmaker to use. When a request is for multiple players, FlexMatch attempts to build a match that includes all players in the request, placing them in the same team and finding additional players as needed to fill the match.  To start matchmaking, provide a unique ticket ID, specify a matchmaking configuration, and include the players to be matched. You must also include any player attributes that are required by the matchmaking configuration's rule set. If successful, a matchmaking ticket is returned with status set to QUEUED.  Track matchmaking events to respond as needed and acquire game session connection information for successfully completed matches. Ticket status updates are tracked using event notification through Amazon Simple Notification Service (SNS), which is defined in the matchmaking configuration.  Learn more    Add FlexMatch to a game client    Set Up FlexMatch event notification    How GameLift FlexMatch works   Related actions   StartMatchmaking | DescribeMatchmaking | StopMatchmaking | AcceptMatch | StartMatchBackfill | All APIs by task

    Args:
        ticket_id(str, optional): A unique identifier for a matchmaking ticket. If no ticket ID is specified here, Amazon GameLift will generate one in the form of a UUID. Use this identifier to track the matchmaking ticket status and retrieve match results. Defaults to None.
        configuration_name(str): Name of the matchmaking configuration to use for this request. Matchmaking configurations must exist in the same Region as this request. You can use either the configuration name or ARN value.
        players(List): Information on each player to be matched. This information must include a player ID, and may contain player attributes and latency data to be used in the matchmaking process. After a successful match, Player objects contain the name of the team the player is assigned to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.matchmaking.init.start(
                ctx, configuration_name=value, players=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.matchmaking.init.start configuration_name=value, players=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="start_matchmaking",
        op_kwargs={
            "TicketId": ticket_id,
            "ConfigurationName": configuration_name,
            "Players": players,
        },
    )


async def stop(hub, ctx, ticket_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a matchmaking ticket or match backfill ticket that is currently being processed. To stop the matchmaking operation, specify the ticket ID. If successful, work on the ticket is stopped, and the ticket status is changed to CANCELLED. This call is also used to turn off automatic backfill for an individual game session. This is for game sessions that are created with a matchmaking configuration that has automatic backfill enabled. The ticket ID is included in the MatchmakerData of an updated game session object, which is provided to the game server.  If the operation is successful, the service sends back an empty JSON struct with the HTTP 200 response (not an empty HTTP body).   Learn more    Add FlexMatch to a game client   Related actions   StartMatchmaking | DescribeMatchmaking | StopMatchmaking | AcceptMatch | StartMatchBackfill | All APIs by task

    Args:
        ticket_id(str): A unique identifier for a matchmaking ticket.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.matchmaking.init.stop(ctx, ticket_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.matchmaking.init.stop ticket_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="stop_matchmaking",
        op_kwargs={"TicketId": ticket_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def modify(
    hub,
    ctx,
    traffic_mirror_filter_id: str,
    add_network_services: List = None,
    remove_network_services: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Allows or restricts mirroring network services.  By default, Amazon DNS network services are not eligible for Traffic Mirror. Use AddNetworkServices to add network services to a Traffic Mirror filter. When a network service is added to the Traffic Mirror filter, all traffic related to that network service will be mirrored. When you no longer want to mirror network services, use RemoveNetworkServices to remove the network services from the Traffic Mirror filter.  For information about filter rule properties, see Network Services in the Traffic Mirroring User Guide .

    Args:
        traffic_mirror_filter_id(str): The ID of the Traffic Mirror filter.
        add_network_services(List, optional): The network service, for example Amazon DNS, that you want to mirror. Defaults to None.
        remove_network_services(List, optional): The network service, for example Amazon DNS, that you no longer want to mirror. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.traffic_mirror.filter_.network_service.modify(
                ctx, traffic_mirror_filter_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.traffic_mirror.filter_.network_service.modify traffic_mirror_filter_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_traffic_mirror_filter_network_services",
        op_kwargs={
            "TrafficMirrorFilterId": traffic_mirror_filter_id,
            "AddNetworkServices": add_network_services,
            "RemoveNetworkServices": remove_network_services,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, web_acl_id: str, resource_type: str = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic Regional documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of resources associated with the specified web ACL.

    Args:
        web_acl_id(str): The unique identifier (ID) of the web ACL for which to list the associated resources.
        resource_type(str, optional): The type of resource to list, either an application load balancer or Amazon API Gateway. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.resource.for_web_acl.list(ctx, web_acl_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.resource.for_web_acl.list web_acl_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="list_resources_for_web_acl",
        op_kwargs={"WebACLId": web_acl_id, "ResourceType": resource_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    repository_name: str,
    branch_name: str,
    parent_commit_id: str = None,
    author_name: str = None,
    email: str = None,
    commit_message: str = None,
    keep_empty_folders: bool = None,
    put_files: List = None,
    delete_files: List = None,
    set_file_modes: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a commit for a repository on the tip of a specified branch.

    Args:
        repository_name(str): The name of the repository where you create the commit.
        branch_name(str): The name of the branch where you create the commit.
        parent_commit_id(str, optional): The ID of the commit that is the parent of the commit you create. Not required if this is an empty repository. Defaults to None.
        author_name(str, optional): The name of the author who created the commit. This information is used as both the author and committer for the commit. Defaults to None.
        email(str, optional): The email address of the person who created the commit. Defaults to None.
        commit_message(str, optional): The commit message you want to include in the commit. Commit messages are limited to 256 KB. If no message is specified, a default message is used. Defaults to None.
        keep_empty_folders(bool, optional): If the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty. If true, a ..gitkeep file is created for empty folders. The default is false. Defaults to None.
        put_files(List, optional): The files to add or update in this commit. Defaults to None.
        delete_files(List, optional): The files to delete in this commit. These files still exist in earlier commits. Defaults to None.
        set_file_modes(List, optional): The file modes to update for files in this commit. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.commit.create(
                ctx, repository_name=value, branch_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.commit.create repository_name=value, branch_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="create_commit",
        op_kwargs={
            "repositoryName": repository_name,
            "branchName": branch_name,
            "parentCommitId": parent_commit_id,
            "authorName": author_name,
            "email": email,
            "commitMessage": commit_message,
            "keepEmptyFolders": keep_empty_folders,
            "putFiles": put_files,
            "deleteFiles": delete_files,
            "setFileModes": set_file_modes,
        },
    )


async def get(hub, ctx, repository_name: str, commit_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a commit, including commit message and committer information.

    Args:
        repository_name(str): The name of the repository to which the commit was made.
        commit_id(str): The commit ID. Commit IDs are the full SHA ID of the commit.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.commit.get(
                ctx, repository_name=value, commit_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.commit.get repository_name=value, commit_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_commit",
        op_kwargs={"repositoryName": repository_name, "commitId": commit_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(hub, ctx, partner_account_id: str, partner_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates your AWS account from a partner account. If PartnerAccountId and PartnerType are null, disassociates your AWS account from all partner accounts.

    Args:
        partner_account_id(str): The partner account ID to disassociate from the AWS account.
        partner_type(str): The partner type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.aws_account.from_partner_account.disassociate(
                ctx, partner_account_id=value, partner_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.aws_account.from_partner_account.disassociate partner_account_id=value, partner_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="disassociate_aws_account_from_partner_account",
        op_kwargs={"PartnerAccountId": partner_account_id, "PartnerType": partner_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, domain_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Provides scheduled Auto-Tune action details for the Elasticsearch domain, such as Auto-Tune action type, description, severity, and scheduled date.

    Args:
        domain_name(str): Specifies the domain name for which you want Auto-Tune action details.
        max_results(int, optional): Set this value to limit the number of results returned. If not specified, defaults to 100. Defaults to None.
        next_token(str, optional): NextToken is sent in case the earlier API call results contain the NextToken. It is used for pagination. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.domain.auto_tune.describe_all(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.domain.auto_tune.describe_all domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="describe_domain_auto_tunes",
        op_kwargs={
            "DomainName": domain_name,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, access_key_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about when the specified access key was last used. The information includes the date and time of last use, along with the Amazon Web Services service and Region that were specified in the last request made with that key.

    Args:
        access_key_id(str): The identifier of an access key. This parameter allows (through its regex pattern) a string of characters that can consist of any upper or lowercased letter or digit.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.access_key.last_used.get(ctx, access_key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.access_key.last_used.get access_key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_access_key_last_used",
        op_kwargs={"AccessKeyId": access_key_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def accept(
    hub, ctx, service_id: str, vpc_endpoint_ids: List, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts one or more interface VPC endpoint connection requests to your VPC endpoint service.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        service_id(str): The ID of the VPC endpoint service.
        vpc_endpoint_ids(List): The IDs of one or more interface VPC endpoints.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.connection.init.accept(
                ctx, service_id=value, vpc_endpoint_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.connection.init.accept service_id=value, vpc_endpoint_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="accept_vpc_endpoint_connections",
        op_kwargs={
            "DryRun": dry_run,
            "ServiceId": service_id,
            "VpcEndpointIds": vpc_endpoint_ids,
        },
    )


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the VPC endpoint connections to your VPC endpoint services, including any endpoints that are pending your acceptance.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filters(List, optional): One or more filters.    service-id - The ID of the service.    vpc-endpoint-owner - The AWS account number of the owner of the endpoint.    vpc-endpoint-state - The state of the endpoint (pendingAcceptance | pending | available | deleting | deleted | rejected | failed).    vpc-endpoint-id - The ID of the endpoint.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned NextToken value. This value can be between 5 and 1,000; if MaxResults is given a value larger than 1,000, only 1,000 results are returned. Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.connection.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.connection.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_vpc_endpoint_connections",
        op_kwargs={
            "DryRun": dry_run,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def reject(
    hub, ctx, service_id: str, vpc_endpoint_ids: List, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Rejects one or more VPC endpoint connection requests to your VPC endpoint service.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        service_id(str): The ID of the service.
        vpc_endpoint_ids(List): The IDs of one or more VPC endpoints.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.connection.init.reject(
                ctx, service_id=value, vpc_endpoint_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.connection.init.reject service_id=value, vpc_endpoint_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="reject_vpc_endpoint_connections",
        op_kwargs={
            "DryRun": dry_run,
            "ServiceId": service_id,
            "VpcEndpointIds": vpc_endpoint_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, fleet_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the device policy configuration for the specified fleet.

    Args:
        fleet_arn(str): The ARN of the fleet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.device.policy_configuration.describe(
                ctx, fleet_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.device.policy_configuration.describe fleet_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="describe_device_policy_configuration",
        op_kwargs={"FleetArn": fleet_arn},
    )


async def update(hub, ctx, fleet_arn: str, device_ca_certificate: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the device policy configuration for the fleet.

    Args:
        fleet_arn(str): The ARN of the fleet.
        device_ca_certificate(str, optional): The certificate chain, including intermediate certificates and the root certificate authority certificate used to issue device certificates. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.device.policy_configuration.update(
                ctx, fleet_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.device.policy_configuration.update fleet_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="update_device_policy_configuration",
        op_kwargs={"FleetArn": fleet_arn, "DeviceCaCertificate": device_ca_certificate},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def allocate(
    hub,
    ctx,
    connection_id: str,
    owner_account: str,
    new_private_virtual_interface_allocation: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

    Provisions a private virtual interface to be owned by the specified account. Virtual interfaces created using this action must be confirmed by the owner using ConfirmPrivateVirtualInterface. Until then, the virtual interface is in the Confirming state and is not available to handle traffic.

    Args:
        connection_id(str): The ID of the connection on which the private virtual interface is provisioned.
        owner_account(str): The ID of the account that owns the virtual private interface.
        new_private_virtual_interface_allocation(Dict): Information about the private virtual interface.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.private_virtual_interface.allocate(
                ctx,
                connection_id=value,
                owner_account=value,
                new_private_virtual_interface_allocation=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.private_virtual_interface.allocate connection_id=value, owner_account=value, new_private_virtual_interface_allocation=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="allocate_private_virtual_interface",
        op_kwargs={
            "connectionId": connection_id,
            "ownerAccount": owner_account,
            "newPrivateVirtualInterfaceAllocation": new_private_virtual_interface_allocation,
        },
    )


async def confirm(
    hub,
    ctx,
    virtual_interface_id: str,
    virtual_gateway_id: str = None,
    direct_connect_gateway_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts ownership of a private virtual interface created by another account. After the virtual interface owner makes this call, the virtual interface is created and attached to the specified virtual private gateway or Direct Connect gateway, and is made available to handle traffic.

    Args:
        virtual_interface_id(str): The ID of the virtual interface.
        virtual_gateway_id(str, optional): The ID of the virtual private gateway. Defaults to None.
        direct_connect_gateway_id(str, optional): The ID of the Direct Connect gateway. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.private_virtual_interface.confirm(
                ctx, virtual_interface_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.private_virtual_interface.confirm virtual_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="confirm_private_virtual_interface",
        op_kwargs={
            "virtualInterfaceId": virtual_interface_id,
            "virtualGatewayId": virtual_gateway_id,
            "directConnectGatewayId": direct_connect_gateway_id,
        },
    )


async def create(
    hub, ctx, connection_id: str, new_private_virtual_interface: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a private virtual interface. A virtual interface is the VLAN that transports Direct Connect traffic. A private virtual interface can be connected to either a Direct Connect gateway or a Virtual Private Gateway (VGW). Connecting the private virtual interface to a Direct Connect gateway enables the possibility for connecting to multiple VPCs, including VPCs in different Regions. Connecting the private virtual interface to a VGW only provides access to a single VPC within the same Region. Setting the MTU of a virtual interface to 9001 (jumbo frames) can cause an update to the underlying physical connection if it wasn't updated to support jumbo frames. Updating the connection disrupts network connectivity for all virtual interfaces associated with the connection for up to 30 seconds. To check whether your connection supports jumbo frames, call DescribeConnections. To check whether your virtual interface supports jumbo frames, call DescribeVirtualInterfaces.

    Args:
        connection_id(str): The ID of the connection.
        new_private_virtual_interface(Dict): Information about the private virtual interface.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.private_virtual_interface.create(
                ctx, connection_id=value, new_private_virtual_interface=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.private_virtual_interface.create connection_id=value, new_private_virtual_interface=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="create_private_virtual_interface",
        op_kwargs={
            "connectionId": connection_id,
            "newPrivateVirtualInterface": new_private_virtual_interface,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(
    hub,
    ctx,
    client_request_token: str,
    external_meeting_id: str = None,
    meeting_host_id: str = None,
    media_region: str = None,
    tags: List = None,
    notifications_configuration: Dict = None,
    attendees: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a new Amazon Chime SDK meeting in the specified media Region, with attendees. For more information about specifying media Regions, see Amazon Chime SDK Media Regions in the Amazon Chime Developer Guide . For more information about the Amazon Chime SDK, see Using the Amazon Chime SDK in the Amazon Chime Developer Guide .

    Args:
        client_request_token(str): The unique identifier for the client request. Use a different token for different meetings.
        external_meeting_id(str, optional): The external meeting ID. Defaults to None.
        meeting_host_id(str, optional): Reserved. Defaults to None.
        media_region(str, optional):  The Region in which to create the meeting. Default: us-east-1 .   Available values: af-south-1 , ap-northeast-1 , ap-northeast-2 , ap-south-1 , ap-southeast-1 , ap-southeast-2 , ca-central-1 , eu-central-1 , eu-north-1 , eu-south-1 , eu-west-1 , eu-west-2 , eu-west-3 , sa-east-1 , us-east-1 , us-east-2 , us-west-1 , us-west-2 . . Defaults to None.
        tags(List, optional): The tag key-value pairs. Defaults to None.
        notifications_configuration(Dict, optional):  The resource target configurations for receiving Amazon Chime SDK meeting and attendee event notifications. The Amazon Chime SDK supports resource targets located in the US East (N. Virginia) AWS Region (us-east-1). . Defaults to None.
        attendees(List, optional): The request containing the attendees to create. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.meeting.with_attendee.create_multiple(
                ctx, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.meeting.with_attendee.create_multiple client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_meeting_with_attendees",
        op_kwargs={
            "ClientRequestToken": client_request_token,
            "ExternalMeetingId": external_meeting_id,
            "MeetingHostId": meeting_host_id,
            "MediaRegion": media_region,
            "Tags": tags,
            "NotificationsConfiguration": notifications_configuration,
            "Attendees": attendees,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(hub, ctx, application_id: str, message_request: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates and sends a direct message.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        message_request(Dict): Specifies the configuration and other settings for a message.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.message.send(
                ctx, application_id=value, message_request=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.message.send application_id=value, message_request=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="send_messages",
        op_kwargs={"ApplicationId": application_id, "MessageRequest": message_request},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    availability_zone: str = None,
    entitlements: List = None,
    media_streams: List = None,
    outputs: List = None,
    source: Dict = None,
    source_failover_config: Dict = None,
    sources: List = None,
    vpc_interfaces: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new flow. The request must include one source. The request optionally can include outputs (up to 50) and entitlements (up to 50).

    Args:
        availability_zone(str, optional): The Availability Zone that you want to create the flow in. These options are limited to the Availability Zones within the current AWS Region. Defaults to None.
        entitlements(List, optional): The entitlements that you want to grant on a flow. Defaults to None.
        media_streams(List, optional): The media streams that you want to add to the flow. You can associate these media streams with sources and outputs on the flow. Defaults to None.
        name(str): The name of the flow.
        outputs(List, optional): The outputs that you want to add to this flow. Defaults to None.
        source(Dict, optional): The settings for the source of the flow. Defaults to None.
        source_failover_config(Dict, optional): The settings for source failover. Defaults to None.
        sources(List, optional): . Defaults to None.
        vpc_interfaces(List, optional): The VPC interfaces you want on the flow. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.init.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.init.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="create_flow",
        op_kwargs={
            "AvailabilityZone": availability_zone,
            "Entitlements": entitlements,
            "MediaStreams": media_streams,
            "Name": name,
            "Outputs": outputs,
            "Source": source,
            "SourceFailoverConfig": source_failover_config,
            "Sources": sources,
            "VpcInterfaces": vpc_interfaces,
        },
    )


async def delete(hub, ctx, flow_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a flow. Before you can delete a flow, you must stop the flow.

    Args:
        flow_arn(str): The ARN of the flow that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.init.delete(ctx, flow_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.init.delete flow_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="delete_flow",
        op_kwargs={"FlowArn": flow_arn},
    )


async def describe(hub, ctx, flow_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Displays the details of a flow. The response includes the flow ARN, name, and Availability Zone, as well as details about the source, outputs, and entitlements.

    Args:
        flow_arn(str): The ARN of the flow that you want to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.init.describe(ctx, flow_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.init.describe flow_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="describe_flow",
        op_kwargs={"FlowArn": flow_arn},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Displays a list of flows that are associated with this account. This request returns a paginated result.

    Args:
        max_results(int, optional): The maximum number of results to return per API request. For example, you submit a ListFlows request with MaxResults set at 5. Although 20 items match your request, the service returns no more than the first 5 items. (The service also returns a NextToken value that you can use to fetch the next batch of results.) The service might return fewer results than the MaxResults value. If MaxResults is not included in the request, the service defaults to pagination with a maximum of 10 results per page. Defaults to None.
        next_token(str, optional): The token that identifies which batch of results that you want to see. For example, you submit a ListFlows request with MaxResults set at 5. The service returns the first batch of results (up to 5) and a NextToken value. To see the next batch of results, you can submit the ListFlows request a second time and specify the NextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="list_flows",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def start(hub, ctx, flow_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts a flow.

    Args:
        flow_arn(str): The ARN of the flow that you want to start.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.init.start(ctx, flow_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.init.start flow_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="start_flow",
        op_kwargs={"FlowArn": flow_arn},
    )


async def stop(hub, ctx, flow_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops a flow.

    Args:
        flow_arn(str): The ARN of the flow that you want to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.init.stop(ctx, flow_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.init.stop flow_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="stop_flow",
        op_kwargs={"FlowArn": flow_arn},
    )


async def update(hub, ctx, flow_arn: str, source_failover_config: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates flow

    Args:
        flow_arn(str): The flow that you want to update.
        source_failover_config(Dict, optional): The settings for source failover. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.init.update(ctx, flow_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.init.update flow_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="update_flow",
        op_kwargs={"FlowArn": flow_arn, "SourceFailoverConfig": source_failover_config},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, admin_account: str) -> None:
    r"""
    **Autogenerated function**

    Sets the Firewall Manager administrator account. The account must be a member of the organization in Organizations whose resources you want to protect. Firewall Manager sets the permissions that allow the account to administer your Firewall Manager policies. The account that you associate with Firewall Manager is called the Firewall Manager administrator account.

    Args:
        admin_account(str): The Amazon Web Services account ID to associate with Firewall Manager as the Firewall Manager administrator account. This must be an Organizations member account. For more information about Organizations, see Managing the Amazon Web Services Accounts in Your Organization. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.admin_account.associate(ctx, admin_account=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.admin_account.associate admin_account=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="associate_admin_account",
        op_kwargs={"AdminAccount": admin_account},
    )


async def disassociate(hub, ctx) -> None:
    r"""
    **Autogenerated function**

    Disassociates the account that has been set as the Firewall Manager administrator account. To set a different account as the administrator account, you must submit an AssociateAdminAccount request.

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.admin_account.disassociate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.admin_account.disassociate
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="fms", operation="disassociate_admin_account", op_kwargs={}
    )


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Returns the Organizations account that is associated with Firewall Manager as the Firewall Manager administrator.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.admin_account.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.admin_account.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="fms", operation="get_admin_account", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def detach(
    hub, ctx, directory_arn: str, index_reference: Dict, target_reference: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Detaches the specified object from the specified index.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) of the directory the index and object exist in.
        index_reference(Dict): A reference to the index object.
        target_reference(Dict): A reference to the object being detached from the index.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.from_index.detach(
                ctx, directory_arn=value, index_reference=value, target_reference=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.from_index.detach directory_arn=value, index_reference=value, target_reference=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="detach_from_index",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "IndexReference": index_reference,
            "TargetReference": target_reference,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides cluster configuration information about the specified Elasticsearch domain, such as the state, creation date, update version, and update date for cluster options.

    Args:
        domain_name(str): The Elasticsearch domain that you want to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.elasticsearch.domain.config.describe(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.elasticsearch.domain.config.describe domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="describe_elasticsearch_domain_config",
        op_kwargs={"DomainName": domain_name},
    )


async def update(
    hub,
    ctx,
    domain_name: str,
    elasticsearch_cluster_config: Dict = None,
    ebs_options: Dict = None,
    snapshot_options: Dict = None,
    vpc_options: Dict = None,
    cognito_options: Dict = None,
    advanced_options: Dict = None,
    access_policies: str = None,
    log_publishing_options: Dict = None,
    domain_endpoint_options: Dict = None,
    advanced_security_options: Dict = None,
    node_to_node_encryption_options: Dict = None,
    encryption_at_rest_options: Dict = None,
    auto_tune_options: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the cluster configuration of the specified Elasticsearch domain, setting as setting the instance type and the number of instances.

    Args:
        domain_name(str): The name of the Elasticsearch domain that you are updating. .
        elasticsearch_cluster_config(Dict, optional): The type and number of instances to instantiate for the domain cluster. Defaults to None.
        ebs_options(Dict, optional): Specify the type and size of the EBS volume that you want to use. . Defaults to None.
        snapshot_options(Dict, optional): Option to set the time, in UTC format, for the daily automated snapshot. Default value is 0 hours. . Defaults to None.
        vpc_options(Dict, optional): Options to specify the subnets and security groups for VPC endpoint. For more information, see Creating a VPC in VPC Endpoints for Amazon Elasticsearch Service Domains. Defaults to None.
        cognito_options(Dict, optional): Options to specify the Cognito user and identity pools for Kibana authentication. For more information, see Amazon Cognito Authentication for Kibana. Defaults to None.
        advanced_options(Dict, optional): Modifies the advanced option to allow references to indices in an HTTP request body. Must be false when configuring access to individual sub-resources. By default, the value is true. See Configuration Advanced Options for more information. Defaults to None.
        access_policies(str, optional): IAM access policy as a JSON-formatted string. Defaults to None.
        log_publishing_options(Dict, optional): Map of LogType and LogPublishingOption, each containing options to publish a given type of Elasticsearch log. Defaults to None.
        domain_endpoint_options(Dict, optional): Options to specify configuration that will be applied to the domain endpoint. Defaults to None.
        advanced_security_options(Dict, optional): Specifies advanced security options. Defaults to None.
        node_to_node_encryption_options(Dict, optional): Specifies the NodeToNodeEncryptionOptions. Defaults to None.
        encryption_at_rest_options(Dict, optional): Specifies the Encryption At Rest Options. Defaults to None.
        auto_tune_options(Dict, optional): Specifies Auto-Tune options. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.elasticsearch.domain.config.update(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.elasticsearch.domain.config.update domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="update_elasticsearch_domain_config",
        op_kwargs={
            "DomainName": domain_name,
            "ElasticsearchClusterConfig": elasticsearch_cluster_config,
            "EBSOptions": ebs_options,
            "SnapshotOptions": snapshot_options,
            "VPCOptions": vpc_options,
            "CognitoOptions": cognito_options,
            "AdvancedOptions": advanced_options,
            "AccessPolicies": access_policies,
            "LogPublishingOptions": log_publishing_options,
            "DomainEndpointOptions": domain_endpoint_options,
            "AdvancedSecurityOptions": advanced_security_options,
            "NodeToNodeEncryptionOptions": node_to_node_encryption_options,
            "EncryptionAtRestOptions": encryption_at_rest_options,
            "AutoTuneOptions": auto_tune_options,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    qualification_type_id: str,
    worker_id: str,
    integer_value: int = None,
    send_notification: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The AssociateQualificationWithWorker operation gives a Worker a Qualification. AssociateQualificationWithWorker does not require that the Worker submit a Qualification request. It gives the Qualification directly to the Worker.   You can only assign a Qualification of a Qualification type that you created (using the CreateQualificationType operation).    Note: AssociateQualificationWithWorker does not affect any pending Qualification requests for the Qualification by the Worker. If you assign a Qualification to a Worker, then later grant a Qualification request made by the Worker, the granting of the request may modify the Qualification score. To resolve a pending Qualification request without affecting the Qualification the Worker already has, reject the request with the RejectQualificationRequest operation.

    Args:
        qualification_type_id(str): The ID of the Qualification type to use for the assigned Qualification.
        worker_id(str):  The ID of the Worker to whom the Qualification is being assigned. Worker IDs are included with submitted HIT assignments and Qualification requests. .
        integer_value(int, optional): The value of the Qualification to assign. Defaults to None.
        send_notification(bool, optional):  Specifies whether to send a notification email message to the Worker saying that the qualification was assigned to the Worker. Note: this is true by default. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.qualification.with_worker.associate(
                ctx, qualification_type_id=value, worker_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.qualification.with_worker.associate qualification_type_id=value, worker_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="associate_qualification_with_worker",
        op_kwargs={
            "QualificationTypeId": qualification_type_id,
            "WorkerId": worker_id,
            "IntegerValue": integer_value,
            "SendNotification": send_notification,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    locale_id: str,
    sort_by: Dict = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of built-in intents provided by Amazon Lex that you can use in your bot.  To use a built-in intent as a the base for your own intent, include the built-in intent signature in the parentIntentSignature parameter when you call the CreateIntent operation. For more information, see CreateIntent.

    Args:
        locale_id(str): The identifier of the language and locale of the intents to list. The string must match one of the supported locales. For more information, see Supported languages.
        sort_by(Dict, optional): Specifies sorting parameters for the list of built-in intents. You can specify that the list be sorted by the built-in intent signature in either ascending or descending order. Defaults to None.
        max_results(int, optional): The maximum number of built-in intents to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned. Defaults to None.
        next_token(str, optional): If the response from the ListBuiltInIntents operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.built_in_.intent.list_all(ctx, locale_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.built_in_.intent.list_all locale_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="list_built_in_intents",
        op_kwargs={
            "localeId": locale_id,
            "sortBy": sort_by,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, endpoint_name: str, endpoint_config_name: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an endpoint using the endpoint configuration specified in the request. Amazon SageMaker uses the endpoint to provision resources and deploy models. You create the endpoint configuration with the CreateEndpointConfig API.   Use this API to deploy models using Amazon SageMaker hosting services.  For an example that calls this method when deploying a model to Amazon SageMaker hosting services, see the Create Endpoint example notebook.    You must not delete an EndpointConfig that is in use by an endpoint that is live or while the UpdateEndpoint or CreateEndpoint operations are being performed on the endpoint. To update an endpoint, you must create a new EndpointConfig.  The endpoint name must be unique within an Amazon Web Services Region in your Amazon Web Services account.  When it receives the request, Amazon SageMaker creates the endpoint, launches the resources (ML compute instances), and deploys the model(s) on them.   When you call CreateEndpoint, a load call is made to DynamoDB to verify that your endpoint configuration exists. When you read data from a DynamoDB table supporting  Eventually Consistent Reads , the response might not reflect the results of a recently completed write operation. The response might include some stale data. If the dependent entities are not yet in DynamoDB, this causes a validation error. If you repeat your read request after a short time, the response should return the latest data. So retry logic is recommended to handle these possible issues. We also recommend that customers call DescribeEndpointConfig before calling CreateEndpoint to minimize the potential impact of a DynamoDB eventually consistent read.  When Amazon SageMaker receives the request, it sets the endpoint status to Creating. After it creates the endpoint, it sets the status to InService. Amazon SageMaker can then process incoming requests for inferences. To check the status of an endpoint, use the DescribeEndpoint API. If any of the models hosted at this endpoint get model data from an Amazon S3 location, Amazon SageMaker uses Amazon Web Services Security Token Service to download model artifacts from the S3 path you provided. Amazon Web Services STS is activated in your IAM user account by default. If you previously deactivated Amazon Web Services STS for a region, you need to reactivate Amazon Web Services STS for that region. For more information, see Activating and Deactivating Amazon Web Services STS in an Amazon Web Services Region in the Amazon Web Services Identity and Access Management User Guide.   To add the IAM role policies for using this API operation, go to the IAM console, and choose Roles in the left navigation pane. Search the IAM role that you want to grant access to use the CreateEndpoint and CreateEndpointConfig API operations, add the following policies to the role.    Option 1: For a full Amazon SageMaker access, search and attach the AmazonSageMakerFullAccess policy.   Option 2: For granting a limited access to an IAM role, paste the following Action elements manually into the JSON file of the IAM role:   "Action": ["sagemaker:CreateEndpoint", "sagemaker:CreateEndpointConfig"]   "Resource": [   "arn:aws:sagemaker:region:account-id:endpoint/endpointName"   "arn:aws:sagemaker:region:account-id:endpoint-config/endpointConfigName"   ]  For more information, see Amazon SageMaker API Permissions: Actions, Permissions, and Resources Reference.

    Args:
        endpoint_name(str): The name of the endpoint.The name must be unique within an Amazon Web Services Region in your Amazon Web Services account. The name is case-insensitive in CreateEndpoint, but the case is preserved and must be matched in .
        endpoint_config_name(str): The name of an endpoint configuration. For more information, see CreateEndpointConfig. .
        tags(List, optional): An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.endpoint.init.create(
                ctx, endpoint_name=value, endpoint_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.endpoint.init.create endpoint_name=value, endpoint_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_endpoint",
        op_kwargs={
            "EndpointName": endpoint_name,
            "EndpointConfigName": endpoint_config_name,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, endpoint_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an endpoint. Amazon SageMaker frees up all of the resources that were deployed when the endpoint was created.  Amazon SageMaker retires any custom KMS key grants associated with the endpoint, meaning you don't need to use the RevokeGrant API call.

    Args:
        endpoint_name(str): The name of the endpoint that you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.endpoint.init.delete(ctx, endpoint_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.endpoint.init.delete endpoint_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_endpoint",
        op_kwargs={"EndpointName": endpoint_name},
    )


async def describe(hub, ctx, endpoint_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the description of an endpoint.

    Args:
        endpoint_name(str): The name of the endpoint.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.endpoint.init.describe(ctx, endpoint_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.endpoint.init.describe endpoint_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_endpoint",
        op_kwargs={"EndpointName": endpoint_name},
    )


async def list_all(
    hub,
    ctx,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
    name_contains: str = None,
    creation_time_before: str = None,
    creation_time_after: str = None,
    last_modified_time_before: str = None,
    last_modified_time_after: str = None,
    status_equals: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists endpoints.

    Args:
        sort_by(str, optional): Sorts the list of results. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Descending. Defaults to None.
        next_token(str, optional): If the result of a ListEndpoints request was truncated, the response includes a NextToken. To retrieve the next set of endpoints, use the token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of endpoints to return in the response. This value defaults to 10. Defaults to None.
        name_contains(str, optional): A string in endpoint names. This filter returns only endpoints whose name contains the specified string. Defaults to None.
        creation_time_before(str, optional): A filter that returns only endpoints that were created before the specified time (timestamp). Defaults to None.
        creation_time_after(str, optional): A filter that returns only endpoints with a creation time greater than or equal to the specified time (timestamp). Defaults to None.
        last_modified_time_before(str, optional):  A filter that returns only endpoints that were modified before the specified timestamp. . Defaults to None.
        last_modified_time_after(str, optional):  A filter that returns only endpoints that were modified after the specified timestamp. . Defaults to None.
        status_equals(str, optional):  A filter that returns only endpoints with the specified status. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.endpoint.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.endpoint.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_endpoints",
        op_kwargs={
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
            "NameContains": name_contains,
            "CreationTimeBefore": creation_time_before,
            "CreationTimeAfter": creation_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
            "StatusEquals": status_equals,
        },
    )


async def update(
    hub,
    ctx,
    endpoint_name: str,
    endpoint_config_name: str,
    retain_all_variant_properties: bool = None,
    exclude_retained_variant_properties: List = None,
    deployment_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deploys the new EndpointConfig specified in the request, switches to using newly created endpoint, and then deletes resources provisioned for the endpoint using the previous EndpointConfig (there is no availability loss).  When Amazon SageMaker receives the request, it sets the endpoint status to Updating. After updating the endpoint, it sets the status to InService. To check the status of an endpoint, use the DescribeEndpoint API.   You must not delete an EndpointConfig in use by an endpoint that is live or while the UpdateEndpoint or CreateEndpoint operations are being performed on the endpoint. To update an endpoint, you must create a new EndpointConfig. If you delete the EndpointConfig of an endpoint that is active or being created or updated you may lose visibility into the instance type the endpoint is using. The endpoint must be deleted in order to stop incurring charges.

    Args:
        endpoint_name(str): The name of the endpoint whose configuration you want to update.
        endpoint_config_name(str): The name of the new endpoint configuration.
        retain_all_variant_properties(bool, optional): When updating endpoint resources, enables or disables the retention of variant properties, such as the instance count or the variant weight. To retain the variant properties of an endpoint when updating it, set RetainAllVariantProperties to true. To use the variant properties specified in a new EndpointConfig call when updating an endpoint, set RetainAllVariantProperties to false. The default is false. Defaults to None.
        exclude_retained_variant_properties(List, optional): When you are updating endpoint resources with UpdateEndpointInput$RetainAllVariantProperties, whose value is set to true, ExcludeRetainedVariantProperties specifies the list of type VariantProperty to override with the values provided by EndpointConfig. If you don't specify a value for ExcludeAllVariantProperties, no variant properties are overridden. . Defaults to None.
        deployment_config(Dict, optional): The deployment configuration for the endpoint to be updated. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.endpoint.init.update(
                ctx, endpoint_name=value, endpoint_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.endpoint.init.update endpoint_name=value, endpoint_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_endpoint",
        op_kwargs={
            "EndpointName": endpoint_name,
            "EndpointConfigName": endpoint_config_name,
            "RetainAllVariantProperties": retain_all_variant_properties,
            "ExcludeRetainedVariantProperties": exclude_retained_variant_properties,
            "DeploymentConfig": deployment_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, template_name: str, template_content: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates an email template. Email templates enable you to send personalized email to one or more destinations in a single API operation. For more information, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        template_name(str): The name of the template you want to create.
        template_content(Dict): The content of the email template, composed of a subject line, an HTML part, and a text-only part.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.template.create(
                ctx, template_name=value, template_content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.template.create template_name=value, template_content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="create_email_template",
        op_kwargs={"TemplateName": template_name, "TemplateContent": template_content},
    )


async def delete(hub, ctx, template_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an email template. You can execute this operation no more than once per second.

    Args:
        template_name(str): The name of the template to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.template.delete(ctx, template_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.template.delete template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="delete_email_template",
        op_kwargs={"TemplateName": template_name},
    )


async def get(hub, ctx, template_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Displays the template object (which includes the subject line, HTML part and text part) for the template you specify. You can execute this operation no more than once per second.

    Args:
        template_name(str): The name of the template you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.template.get(ctx, template_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.template.get template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="get_email_template",
        op_kwargs={"TemplateName": template_name},
    )


async def list_all(hub, ctx, next_token: str = None, page_size: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the email templates present in your Amazon SES account in the current AWS Region. You can execute this operation no more than once per second.

    Args:
        next_token(str, optional): A token returned from a previous call to ListEmailTemplates to indicate the position in the list of email templates. Defaults to None.
        page_size(int, optional): The number of results to show in a single call to ListEmailTemplates. If the number of results is larger than the number you specified in this parameter, then the response includes a NextToken element, which you can use to obtain additional results. The value you specify has to be at least 1, and can be no more than 10. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.template.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.template.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="list_email_templates",
        op_kwargs={"NextToken": next_token, "PageSize": page_size},
    )


async def update(hub, ctx, template_name: str, template_content: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Updates an email template. Email templates enable you to send personalized email to one or more destinations in a single API operation. For more information, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        template_name(str): The name of the template you want to update.
        template_content(Dict): The content of the email template, composed of a subject line, an HTML part, and a text-only part.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.template.update(
                ctx, template_name=value, template_content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.template.update template_name=value, template_content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="update_email_template",
        op_kwargs={"TemplateName": template_name, "TemplateContent": template_content},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, signature: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a built-in intent. This operation requires permission for the lex:GetBuiltinIntent action.

    Args:
        signature(str): The unique identifier for a built-in intent. To find the signature for an intent, see Standard Built-in Intents in the Alexa Skills Kit.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.builtin.intent.get(ctx, signature=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.builtin.intent.get signature=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_builtin_intent",
        op_kwargs={"signature": signature},
    )


async def get_all(
    hub,
    ctx,
    locale: str = None,
    signature_contains: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of built-in intents that meet the specified criteria. This operation requires permission for the lex:GetBuiltinIntents action.

    Args:
        locale(str, optional): A list of locales that the intent supports. Defaults to None.
        signature_contains(str, optional): Substring to match in built-in intent signatures. An intent will be returned if any part of its signature matches the substring. For example, "xyz" matches both "xyzabc" and "abcxyz." To find the signature for an intent, see Standard Built-in Intents in the Alexa Skills Kit. Defaults to None.
        next_token(str, optional): A pagination token that fetches the next page of intents. If this API call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of intents, use the pagination token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of intents to return in the response. The default is 10. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.builtin.intent.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.builtin.intent.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_builtin_intents",
        op_kwargs={
            "locale": locale,
            "signatureContains": signature_contains,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, home_region: str, target: Dict, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    This API sets up the home region for the calling account only.

    Args:
        home_region(str): The name of the home region of the calling account.
        target(Dict): The account for which this command sets up a home region control. The Target is always of type ACCOUNT.
        dry_run(bool, optional): Optional Boolean flag to indicate whether any effect should take place. It tests whether the caller has permission to make the call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.migrationhub_config_home_region.control.create(
                ctx, home_region=value, target=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.migrationhub_config_home_region.control.create home_region=value, target=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="migrationhub-config",
        operation="create_home_region_control",
        op_kwargs={"HomeRegion": home_region, "Target": target, "DryRun": dry_run},
    )


async def describe_all(
    hub,
    ctx,
    control_id: str = None,
    home_region: str = None,
    target: Dict = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This API permits filtering on the ControlId and HomeRegion fields.

    Args:
        control_id(str, optional): The ControlID is a unique identifier string of your HomeRegionControl object. Defaults to None.
        home_region(str, optional): The name of the home region you'd like to view. Defaults to None.
        target(Dict, optional): The target parameter specifies the identifier to which the home region is applied, which is always of type ACCOUNT. It applies the home region to the current ACCOUNT. Defaults to None.
        max_results(int, optional): The maximum number of filtering results to display per page. . Defaults to None.
        next_token(str, optional): If a NextToken was returned by a previous call, more results are available. To retrieve the next page of results, make the call again using the returned token in NextToken. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.migrationhub_config_home_region.control.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.migrationhub_config_home_region.control.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="migrationhub-config",
        operation="describe_home_region_controls",
        op_kwargs={
            "ControlId": control_id,
            "HomeRegion": home_region,
            "Target": target,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Assigns one or more tags (key-value pairs) to the specified Amazon Connect Customer Profiles resource. Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values. In Connect Customer Profiles, domains, profile object types, and integrations can be tagged. Tags don't have any semantic meaning to AWS and are interpreted strictly as strings of characters. You can use the TagResource action with a resource that already has tags. If you specify a new tag key, this tag is appended to the list of tags associated with the resource. If you specify a tag key that is already associated with the resource, the new tag value that you specify replaces the previous value for that tag. You can associate as many as 50 tags with a resource.

    Args:
        resource_arn(str): The ARN of the resource that you're adding tags to.
        tags(Dict): The tags used to organize, track, or control access for this resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.resource.tag(
                ctx, resource_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="tag_resource",
        op_kwargs={"resourceArn": resource_arn, "tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more tags from the specified Amazon Connect Customer Profiles resource. In Connect Customer Profiles, domains, profile object types, and integrations can be tagged.

    Args:
        resource_arn(str): The ARN of the resource from which you are removing tags.
        tag_keys(List): The list of tag keys to remove from the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="untag_resource",
        op_kwargs={"resourceArn": resource_arn, "tagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    rule_id: str,
    detector_id: str,
    expression: str,
    language: str,
    outcomes: List,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a rule for use with the specified detector.

    Args:
        rule_id(str): The rule ID.
        detector_id(str): The detector ID for the rule's parent detector.
        description(str, optional): The rule description. Defaults to None.
        expression(str): The rule expression.
        language(str): The language of the rule.
        outcomes(List): The outcome or outcomes returned when the rule expression matches.
        tags(List, optional): A collection of key and value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.rule.init.create(
                ctx,
                rule_id=value,
                detector_id=value,
                expression=value,
                language=value,
                outcomes=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.rule.init.create rule_id=value, detector_id=value, expression=value, language=value, outcomes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="create_rule",
        op_kwargs={
            "ruleId": rule_id,
            "detectorId": detector_id,
            "description": description,
            "expression": expression,
            "language": language,
            "outcomes": outcomes,
            "tags": tags,
        },
    )


async def delete(hub, ctx, rule: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the rule. You cannot delete a rule if it is used by an ACTIVE or INACTIVE detector version. When you delete a rule, Amazon Fraud Detector permanently deletes that rule and the data is no longer stored in Amazon Fraud Detector.

    Args:
        rule(Dict): A rule.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.rule.init.delete(ctx, rule=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.rule.init.delete rule=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="delete_rule",
        op_kwargs={"rule": rule},
    )


async def get_all(
    hub,
    ctx,
    detector_id: str,
    rule_id: str = None,
    rule_version: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Get all rules for a detector (paginated) if ruleId and ruleVersion are not specified. Gets all rules for the detector and the ruleId if present (paginated). Gets a specific rule if both the ruleId and the ruleVersion are specified. This is a paginated API. Providing null maxResults results in retrieving maximum of 100 records per page. If you provide maxResults the value must be between 50 and 100. To get the next page result, a provide a pagination token from GetRulesResult as part of your request. Null pagination token fetches the records from the beginning.

    Args:
        rule_id(str, optional): The rule ID. Defaults to None.
        detector_id(str): The detector ID.
        rule_version(str, optional): The rule version. Defaults to None.
        next_token(str, optional): The next page token. Defaults to None.
        max_results(int, optional): The maximum number of rules to return for the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.rule.init.get_all(ctx, detector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.rule.init.get_all detector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="get_rules",
        op_kwargs={
            "ruleId": rule_id,
            "detectorId": detector_id,
            "ruleVersion": rule_version,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"import_": "import"}


async def import_(hub, ctx, role_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Allows application import from AWS Migration Hub.

    Args:
        role_name(str, optional): The name of the service role. If you omit this parameter, we create a service-linked role for AWS Migration Hub in your account. Otherwise, the role that you provide must have the policy and trust policy described in the AWS Migration Hub User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.app.catalog.import(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.app.catalog.import
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="import_app_catalog",
        op_kwargs={"roleName": role_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(
    hub,
    ctx,
    instance_id: str,
    affinity: str = None,
    group_name: str = None,
    host_id: str = None,
    tenancy: str = None,
    partition_number: int = None,
    host_resource_group_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the placement attributes for a specified instance. You can do the following:   Modify the affinity between an instance and a Dedicated Host. When affinity is set to host and the instance is not associated with a specific Dedicated Host, the next time the instance is launched, it is automatically associated with the host on which it lands. If the instance is restarted or rebooted, this relationship persists.   Change the Dedicated Host with which an instance is associated.   Change the instance tenancy of an instance from host to dedicated, or from dedicated to host.   Move an instance to or from a placement group.   At least one attribute for affinity, host ID, tenancy, or placement group name must be specified in the request. Affinity and tenancy can be modified in the same request. To modify the host ID, tenancy, placement group, or partition for an instance, the instance must be in the stopped state.

    Args:
        affinity(str, optional): The affinity setting for the instance. Defaults to None.
        group_name(str, optional): The name of the placement group in which to place the instance. For spread placement groups, the instance must have a tenancy of default. For cluster and partition placement groups, the instance must have a tenancy of default or dedicated. To remove an instance from a placement group, specify an empty string (""). Defaults to None.
        host_id(str, optional): The ID of the Dedicated Host with which to associate the instance. Defaults to None.
        instance_id(str): The ID of the instance that you are modifying.
        tenancy(str, optional): The tenancy for the instance. Defaults to None.
        partition_number(int, optional): Reserved for future use. Defaults to None.
        host_resource_group_arn(str, optional): The ARN of the host resource group in which to place the instance. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.placement.modify(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.placement.modify instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_instance_placement",
        op_kwargs={
            "Affinity": affinity,
            "GroupName": group_name,
            "HostId": host_id,
            "InstanceId": instance_id,
            "Tenancy": tenancy,
            "PartitionNumber": partition_number,
            "HostResourceGroupArn": host_resource_group_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    service_code: str,
    quota_code: str,
    status: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the quota increase requests for the specified quota.

    Args:
        service_code(str): The service identifier.
        quota_code(str): The quota identifier.
        status(str, optional): The status value of the quota increase request. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, if any, make another call with the token returned from this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.service_quotas.requested_service_quota_change.history.by_quota.list(
                ctx, service_code=value, quota_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.service_quotas.requested_service_quota_change.history.by_quota.list service_code=value, quota_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="service-quotas",
        operation="list_requested_service_quota_change_history_by_quota",
        op_kwargs={
            "ServiceCode": service_code,
            "QuotaCode": quota_code,
            "Status": status,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def update(
    hub,
    ctx,
    instance_id: str,
    contact_flow_id: str,
    name: str = None,
    description: str = None,
) -> None:
    r"""
    **Autogenerated function**

    The name of the contact flow. You can also create and update contact flows using the Amazon Connect Flow language.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance.
        contact_flow_id(str): The identifier of the contact flow.
        name(str, optional): The name of the contact flow. Defaults to None.
        description(str, optional): The description of the contact flow. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.contact.flow.name.update(
                ctx, instance_id=value, contact_flow_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.contact.flow.name.update instance_id=value, contact_flow_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="update_contact_flow_name",
        op_kwargs={
            "InstanceId": instance_id,
            "ContactFlowId": contact_flow_id,
            "Name": name,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, name: str, default_job_timeout_minutes: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a project.

    Args:
        name(str): The project's name.
        default_job_timeout_minutes(int, optional): Sets the execution timeout value (in minutes) for a project. All test runs in this project use the specified execution timeout value unless overridden when scheduling a run. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.project.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.project.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="create_project",
        op_kwargs={
            "name": name,
            "defaultJobTimeoutMinutes": default_job_timeout_minutes,
        },
    )


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an AWS Device Farm project, given the project ARN.  Deleting this resource does not stop an in-progress run.

    Args:
        arn(str): Represents the Amazon Resource Name (ARN) of the Device Farm project to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.project.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.project.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="delete_project",
        op_kwargs={"arn": arn},
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a project.

    Args:
        arn(str): The project's ARN.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.project.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.project.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="devicefarm", operation="get_project", op_kwargs={"arn": arn}
    )


async def list_all(hub, ctx, arn: str = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about projects.

    Args:
        arn(str, optional): Optional. If no Amazon Resource Name (ARN) is specified, then AWS Device Farm returns a list of all projects for the AWS account. You can also specify a project ARN. Defaults to None.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.project.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.project.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_projects",
        op_kwargs={"arn": arn, "nextToken": next_token},
    )


async def update(
    hub, ctx, arn: str, name: str = None, default_job_timeout_minutes: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the specified project name, given the project ARN and a new name.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the project whose name to update.
        name(str, optional): A string that represents the new name of the project that you are updating. Defaults to None.
        default_job_timeout_minutes(int, optional): The number of minutes a test run in the project executes before it times out. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.project.update(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.project.update arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="update_project",
        op_kwargs={
            "arn": arn,
            "name": name,
            "defaultJobTimeoutMinutes": default_job_timeout_minutes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    role_alias: str,
    role_arn: str,
    credential_duration_seconds: int = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a role alias.

    Args:
        role_alias(str): The role alias that points to a role ARN. This allows you to change the role without having to update the device.
        role_arn(str): The role ARN.
        credential_duration_seconds(int, optional): How long (in seconds) the credentials will be valid. Defaults to None.
        tags(List, optional): Metadata which can be used to manage the role alias.  For URI Request parameters use format: ...key1=value1&key2=value2... For the CLI command-line parameter use format: &&tags "key1=value1&key2=value2..." For the cli-input-json file use format: "tags": "key1=value1&key2=value2..." . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.role_alias.create(ctx, role_alias=value, role_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.role_alias.create role_alias=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_role_alias",
        op_kwargs={
            "roleAlias": role_alias,
            "roleArn": role_arn,
            "credentialDurationSeconds": credential_duration_seconds,
            "tags": tags,
        },
    )


async def delete(hub, ctx, role_alias: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a role alias

    Args:
        role_alias(str): The role alias to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.role_alias.delete(ctx, role_alias=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.role_alias.delete role_alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_role_alias",
        op_kwargs={"roleAlias": role_alias},
    )


async def describe(hub, ctx, role_alias: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a role alias.

    Args:
        role_alias(str): The role alias to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.role_alias.describe(ctx, role_alias=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.role_alias.describe role_alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_role_alias",
        op_kwargs={"roleAlias": role_alias},
    )


async def update(
    hub,
    ctx,
    role_alias: str,
    role_arn: str = None,
    credential_duration_seconds: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a role alias.

    Args:
        role_alias(str): The role alias to update.
        role_arn(str, optional): The role ARN. Defaults to None.
        credential_duration_seconds(int, optional): The number of seconds the credential will be valid. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.role_alias.update(ctx, role_alias=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.role_alias.update role_alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_role_alias",
        op_kwargs={
            "roleAlias": role_alias,
            "roleArn": role_arn,
            "credentialDurationSeconds": credential_duration_seconds,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, log_group_name: str, kms_key_id: str = None, tags: Dict = None
) -> None:
    r"""
    **Autogenerated function**

    Creates a log group with the specified name. You can create up to 20,000 log groups per account. You must use the following guidelines when naming a log group:   Log group names must be unique within a region for an AWS account.   Log group names can be between 1 and 512 characters long.   Log group names consist of the following characters: a-z, A-Z, 0-9, '_' (underscore), '-' (hyphen), '/' (forward slash), '.' (period), and '#' (number sign)   When you create a log group, by default the log events in the log group never expire. To set a retention policy so that events expire and are deleted after a specified time, use PutRetentionPolicy. If you associate a AWS Key Management Service (AWS KMS) customer master key (CMK) with the log group, ingested data is encrypted using the CMK. This association is stored as long as the data encrypted with the CMK is still within Amazon CloudWatch Logs. This enables Amazon CloudWatch Logs to decrypt this data whenever it is requested. If you attempt to associate a CMK with the log group but the CMK does not exist or the CMK is disabled, you receive an InvalidParameterException error.    CloudWatch Logs supports only symmetric CMKs. Do not associate an asymmetric CMK with your log group. For more information, see Using Symmetric and Asymmetric Keys.

    Args:
        log_group_name(str): The name of the log group.
        kms_key_id(str, optional): The Amazon Resource Name (ARN) of the CMK to use when encrypting log data. For more information, see Amazon Resource Names - AWS Key Management Service (AWS KMS). Defaults to None.
        tags(Dict, optional): The key-value pairs to use for the tags. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.log.group.init.create(ctx, log_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.log.group.init.create log_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="create_log_group",
        op_kwargs={
            "logGroupName": log_group_name,
            "kmsKeyId": kms_key_id,
            "tags": tags,
        },
    )


async def delete(hub, ctx, log_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified log group and permanently deletes all the archived log events associated with the log group.

    Args:
        log_group_name(str): The name of the log group.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.log.group.init.delete(ctx, log_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.log.group.init.delete log_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="delete_log_group",
        op_kwargs={"logGroupName": log_group_name},
    )


async def describe_all(
    hub,
    ctx,
    log_group_name_prefix: str = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the specified log groups. You can list all your log groups or filter the results by prefix. The results are ASCII-sorted by log group name.

    Args:
        log_group_name_prefix(str, optional): The prefix to match. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        limit(int, optional): The maximum number of items returned. If you don't specify a value, the default is up to 50 items. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.log.group.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.log.group.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="describe_log_groups",
        op_kwargs={
            "logGroupNamePrefix": log_group_name_prefix,
            "nextToken": next_token,
            "limit": limit,
        },
    )


async def tag(hub, ctx, log_group_name: str, tags: Dict) -> None:
    r"""
    **Autogenerated function**

    Adds or updates the specified tags for the specified log group. To list the tags for a log group, use ListTagsLogGroup. To remove tags, use UntagLogGroup. For more information about tags, see Tag Log Groups in Amazon CloudWatch Logs in the Amazon CloudWatch Logs User Guide.

    Args:
        log_group_name(str): The name of the log group.
        tags(Dict): The key-value pairs to use for the tags.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.log.group.init.tag(ctx, log_group_name=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.log.group.init.tag log_group_name=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="tag_log_group",
        op_kwargs={"logGroupName": log_group_name, "tags": tags},
    )


async def untag(hub, ctx, log_group_name: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Removes the specified tags from the specified log group. To list the tags for a log group, use ListTagsLogGroup. To add tags, use TagLogGroup.

    Args:
        log_group_name(str): The name of the log group.
        tags(List): The tag keys. The corresponding tags are removed from the log group.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.log.group.init.untag(ctx, log_group_name=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.log.group.init.untag log_group_name=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="untag_log_group",
        op_kwargs={"logGroupName": log_group_name, "tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete_multiple(
    hub, ctx, reserved_instances_ids: List, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the queued purchases for the specified Reserved Instances.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        reserved_instances_ids(List): The IDs of the Reserved Instances.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.queued_reserved_instance.delete_multiple(
                ctx, reserved_instances_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.queued_reserved_instance.delete_multiple reserved_instances_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_queued_reserved_instances",
        op_kwargs={"DryRun": dry_run, "ReservedInstancesIds": reserved_instances_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(hub, ctx, sort_order: str = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of build IDs, with each build ID representing a single build.

    Args:
        sort_order(str, optional): The order to list build IDs. Valid values include:    ASCENDING: List the build IDs in ascending order by build ID.    DESCENDING: List the build IDs in descending order by build ID.  . Defaults to None.
        next_token(str, optional): During a previous call, if there are more than 100 items in the list, only the first 100 items are returned, along with a unique string called a nextToken. To get the next batch of items in the list, call this operation again, adding the next token to the call. To get all of the items in the list, keep calling this operation with each subsequent next token that is returned, until no more next tokens are returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.build.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.build.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="list_builds",
        op_kwargs={"sortOrder": sort_order, "nextToken": next_token},
    )


async def retry(hub, ctx, id_: str = None, idempotency_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Restarts a build.

    Args:
        id_(str, optional): Specifies the identifier of the build to restart. Defaults to None.
        idempotency_token(str, optional): A unique, case sensitive identifier you provide to ensure the idempotency of the RetryBuild request. The token is included in the RetryBuild request and is valid for five minutes. If you repeat the RetryBuild request with the same token, but change a parameter, AWS CodeBuild returns a parameter mismatch error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.build.init.retry(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.build.init.retry
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="retry_build",
        op_kwargs={"id": id_, "idempotencyToken": idempotency_token},
    )


async def start(
    hub,
    ctx,
    project_name: str,
    secondary_sources_override: List = None,
    secondary_sources_version_override: List = None,
    source_version: str = None,
    artifacts_override: Dict = None,
    secondary_artifacts_override: List = None,
    environment_variables_override: List = None,
    source_type_override: str = None,
    source_location_override: str = None,
    source_auth_override: Dict = None,
    git_clone_depth_override: int = None,
    git_submodules_config_override: Dict = None,
    buildspec_override: str = None,
    insecure_ssl_override: bool = None,
    report_build_status_override: bool = None,
    build_status_config_override: Dict = None,
    environment_type_override: str = None,
    image_override: str = None,
    compute_type_override: str = None,
    certificate_override: str = None,
    cache_override: Dict = None,
    service_role_override: str = None,
    privileged_mode_override: bool = None,
    timeout_in_minutes_override: int = None,
    queued_timeout_in_minutes_override: int = None,
    encryption_key_override: str = None,
    idempotency_token: str = None,
    logs_config_override: Dict = None,
    registry_credential_override: Dict = None,
    image_pull_credentials_type_override: str = None,
    debug_session_enabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts running a build.

    Args:
        project_name(str): The name of the AWS CodeBuild build project to start running a build.
        secondary_sources_override(List, optional):  An array of ProjectSource objects. . Defaults to None.
        secondary_sources_version_override(List, optional):  An array of ProjectSourceVersion objects that specify one or more versions of the project's secondary sources to be used for this build only. . Defaults to None.
        source_version(str, optional): The version of the build input to be built, for this build only. If not specified, the latest version is used. If specified, the contents depends on the source provider:  AWS CodeCommit  The commit ID, branch, or Git tag to use.  GitHub  The commit ID, pull request ID, branch name, or tag name that corresponds to the version of the source code you want to build. If a pull request ID is specified, it must use the format pr/pull-request-ID (for example pr/25). If a branch name is specified, the branch's HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is used.  Bitbucket  The commit ID, branch name, or tag name that corresponds to the version of the source code you want to build. If a branch name is specified, the branch's HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is used.  Amazon S3  The version ID of the object that represents the build input ZIP file to use.   If sourceVersion is specified at the project level, then this sourceVersion (at the build level) takes precedence.  For more information, see Source Version Sample with CodeBuild in the AWS CodeBuild User Guide. . Defaults to None.
        artifacts_override(Dict, optional): Build output artifact settings that override, for this build only, the latest ones already defined in the build project. Defaults to None.
        secondary_artifacts_override(List, optional):  An array of ProjectArtifacts objects. . Defaults to None.
        environment_variables_override(List, optional): A set of environment variables that overrides, for this build only, the latest ones already defined in the build project. Defaults to None.
        source_type_override(str, optional): A source input type, for this build, that overrides the source input defined in the build project. Defaults to None.
        source_location_override(str, optional): A location that overrides, for this build, the source location for the one defined in the build project. Defaults to None.
        source_auth_override(Dict, optional): An authorization type for this build that overrides the one defined in the build project. This override applies only if the build project's source is BitBucket or GitHub. Defaults to None.
        git_clone_depth_override(int, optional): The user-defined depth of history, with a minimum value of 0, that overrides, for this build only, any previous depth of history defined in the build project. Defaults to None.
        git_submodules_config_override(Dict, optional):  Information about the Git submodules configuration for this build of an AWS CodeBuild build project. . Defaults to None.
        buildspec_override(str, optional): A buildspec file declaration that overrides, for this build only, the latest one already defined in the build project.  If this value is set, it can be either an inline buildspec definition, the path to an alternate buildspec file relative to the value of the built-in CODEBUILD_SRC_DIR environment variable, or the path to an S3 bucket. The bucket must be in the same AWS Region as the build project. Specify the buildspec file using its ARN (for example, arn:aws:s3:::my-codebuild-sample2/buildspec.yml). If this value is not provided or is set to an empty string, the source code must contain a buildspec file in its root directory. For more information, see Buildspec File Name and Storage Location. . Defaults to None.
        insecure_ssl_override(bool, optional): Enable this flag to override the insecure SSL setting that is specified in the build project. The insecure SSL setting determines whether to ignore SSL warnings while connecting to the project source code. This override applies only if the build's source is GitHub Enterprise. Defaults to None.
        report_build_status_override(bool, optional):  Set to true to report to your source provider the status of a build's start and completion. If you use this option with a source provider other than GitHub, GitHub Enterprise, or Bitbucket, an invalidInputException is thrown.  To be able to report the build status to the source provider, the user associated with the source provider must have write access to the repo. If the user does not have write access, the build status cannot be updated. For more information, see Source provider access in the AWS CodeBuild User Guide.   The status of a build triggered by a webhook is always reported to your source provider.  . Defaults to None.
        build_status_config_override(Dict, optional): Contains information that defines how the build project reports the build status to the source provider. This option is only used when the source provider is GITHUB, GITHUB_ENTERPRISE, or BITBUCKET. Defaults to None.
        environment_type_override(str, optional): A container type for this build that overrides the one specified in the build project. Defaults to None.
        image_override(str, optional): The name of an image for this build that overrides the one specified in the build project. Defaults to None.
        compute_type_override(str, optional): The name of a compute type for this build that overrides the one specified in the build project. Defaults to None.
        certificate_override(str, optional): The name of a certificate for this build that overrides the one specified in the build project. Defaults to None.
        cache_override(Dict, optional): A ProjectCache object specified for this build that overrides the one defined in the build project. Defaults to None.
        service_role_override(str, optional): The name of a service role for this build that overrides the one specified in the build project. Defaults to None.
        privileged_mode_override(bool, optional): Enable this flag to override privileged mode in the build project. Defaults to None.
        timeout_in_minutes_override(int, optional): The number of build timeout minutes, from 5 to 480 (8 hours), that overrides, for this build only, the latest setting already defined in the build project. Defaults to None.
        queued_timeout_in_minutes_override(int, optional):  The number of minutes a build is allowed to be queued before it times out. . Defaults to None.
        encryption_key_override(str, optional): The AWS Key Management Service (AWS KMS) customer master key (CMK) that overrides the one specified in the build project. The CMK key encrypts the build output artifacts.   You can use a cross-account KMS key to encrypt the build output artifacts if your service role has permission to that key.   You can specify either the Amazon Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the format alias/<alias-name>). Defaults to None.
        idempotency_token(str, optional): A unique, case sensitive identifier you provide to ensure the idempotency of the StartBuild request. The token is included in the StartBuild request and is valid for 5 minutes. If you repeat the StartBuild request with the same token, but change a parameter, AWS CodeBuild returns a parameter mismatch error. . Defaults to None.
        logs_config_override(Dict, optional):  Log settings for this build that override the log settings defined in the build project. . Defaults to None.
        registry_credential_override(Dict, optional):  The credentials for access to a private registry. . Defaults to None.
        image_pull_credentials_type_override(str, optional): The type of credentials AWS CodeBuild uses to pull images in your build. There are two valid values:   CODEBUILD  Specifies that AWS CodeBuild uses its own credentials. This requires that you modify your ECR repository policy to trust AWS CodeBuild's service principal.  SERVICE_ROLE  Specifies that AWS CodeBuild uses your build project's service role.    When using a cross-account or private registry image, you must use SERVICE_ROLE credentials. When using an AWS CodeBuild curated image, you must use CODEBUILD credentials. . Defaults to None.
        debug_session_enabled(bool, optional): Specifies if session debugging is enabled for this build. For more information, see Viewing a running build in Session Manager. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.build.init.start(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.build.init.start project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="start_build",
        op_kwargs={
            "projectName": project_name,
            "secondarySourcesOverride": secondary_sources_override,
            "secondarySourcesVersionOverride": secondary_sources_version_override,
            "sourceVersion": source_version,
            "artifactsOverride": artifacts_override,
            "secondaryArtifactsOverride": secondary_artifacts_override,
            "environmentVariablesOverride": environment_variables_override,
            "sourceTypeOverride": source_type_override,
            "sourceLocationOverride": source_location_override,
            "sourceAuthOverride": source_auth_override,
            "gitCloneDepthOverride": git_clone_depth_override,
            "gitSubmodulesConfigOverride": git_submodules_config_override,
            "buildspecOverride": buildspec_override,
            "insecureSslOverride": insecure_ssl_override,
            "reportBuildStatusOverride": report_build_status_override,
            "buildStatusConfigOverride": build_status_config_override,
            "environmentTypeOverride": environment_type_override,
            "imageOverride": image_override,
            "computeTypeOverride": compute_type_override,
            "certificateOverride": certificate_override,
            "cacheOverride": cache_override,
            "serviceRoleOverride": service_role_override,
            "privilegedModeOverride": privileged_mode_override,
            "timeoutInMinutesOverride": timeout_in_minutes_override,
            "queuedTimeoutInMinutesOverride": queued_timeout_in_minutes_override,
            "encryptionKeyOverride": encryption_key_override,
            "idempotencyToken": idempotency_token,
            "logsConfigOverride": logs_config_override,
            "registryCredentialOverride": registry_credential_override,
            "imagePullCredentialsTypeOverride": image_pull_credentials_type_override,
            "debugSessionEnabled": debug_session_enabled,
        },
    )


async def stop(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Attempts to stop running a build.

    Args:
        id_(str): The ID of the build.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.build.init.stop(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.build.init.stop id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="codebuild", operation="stop_build", op_kwargs={"id": id_}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the properties associated with a topic detection job. Use this operation to get the status of a detection job.

    Args:
        job_id(str): The identifier assigned by the user to the detection job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.topic_detection_job.describe(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.topic_detection_job.describe job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="describe_topics_detection_job",
        op_kwargs={"JobId": job_id},
    )


async def list_all(
    hub, ctx, filter_: Dict = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the topic detection jobs that you have submitted.

    Args:
        filter_(Dict, optional): Filters the jobs that are returned. Jobs can be filtered on their name, status, or the date and time that they were submitted. You can set only one filter at a time. Defaults to None.
        next_token(str, optional): Identifies the next page of results to return. Defaults to None.
        max_results(int, optional): The maximum number of results to return in each page. The default is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.topic_detection_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.topic_detection_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="list_topics_detection_jobs",
        op_kwargs={
            "Filter": filter_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(
    hub,
    ctx,
    input_data_config: Dict,
    output_data_config: Dict,
    data_access_role_arn: str,
    job_name: str = None,
    number_of_topics: int = None,
    client_request_token: str = None,
    volume_kms_key_id: str = None,
    vpc_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an asynchronous topic detection job. Use the DescribeTopicDetectionJob operation to track the status of a job.

    Args:
        input_data_config(Dict): Specifies the format and location of the input data for the job.
        output_data_config(Dict): Specifies where to send the output files. The output is a compressed archive with two files, topic-terms.csv that lists the terms associated with each topic, and doc-topics.csv that lists the documents associated with each topic.
        data_access_role_arn(str): The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that grants Amazon Comprehend read access to your input data. For more information, see https://docs.aws.amazon.com/comprehend/latest/dg/access-control-managing-permissions.html#auth-role-permissions.
        job_name(str, optional): The identifier of the job. Defaults to None.
        number_of_topics(int, optional): The number of topics to detect. Defaults to None.
        client_request_token(str, optional): A unique identifier for the request. If you do not set the client request token, Amazon Comprehend generates one. Defaults to None.
        volume_kms_key_id(str, optional): ID for the AWS Key Management Service (KMS) key that Amazon Comprehend uses to encrypt data on the storage volume attached to the ML compute instance(s) that process the analysis job. The VolumeKmsKeyId can be either of the following formats:   KMS Key ID: "1234abcd-12ab-34cd-56ef-1234567890ab"    Amazon Resource Name (ARN) of a KMS Key: "arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"   . Defaults to None.
        vpc_config(Dict, optional): Configuration parameters for an optional private Virtual Private Cloud (VPC) containing the resources you are using for your topic detection job. For more information, see Amazon VPC. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.topic_detection_job.start(
                ctx, input_data_config=value, output_data_config=value, data_access_role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.topic_detection_job.start input_data_config=value, output_data_config=value, data_access_role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="start_topics_detection_job",
        op_kwargs={
            "InputDataConfig": input_data_config,
            "OutputDataConfig": output_data_config,
            "DataAccessRoleArn": data_access_role_arn,
            "JobName": job_name,
            "NumberOfTopics": number_of_topics,
            "ClientRequestToken": client_request_token,
            "VolumeKmsKeyId": volume_kms_key_id,
            "VpcConfig": vpc_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    bucket: str,
    object_key: str,
    name: str = None,
    tag_specifications: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a task that restores an AMI from an S3 object that was previously created by using CreateStoreImageTask. To use this API, you must have the required permissions. For more information, see Permissions for storing and restoring AMIs using S3 in the Amazon Elastic Compute Cloud User Guide. For more information, see Store and restore an AMI using S3 in the Amazon Elastic Compute Cloud User Guide.

    Args:
        bucket(str): The name of the S3 bucket that contains the stored AMI object.
        object_key(str): The name of the stored AMI object in the bucket.
        name(str, optional): The name for the restored AMI. The name must be unique for AMIs in the Region for this account. If you do not provide a name, the new AMI gets the same name as the original AMI. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the AMI and snapshots on restoration. You can tag the AMI, the snapshots, or both.   To tag the AMI, the value for ResourceType must be image.   To tag the snapshots, the value for ResourceType must be snapshot. The same tag is applied to all of the snapshots that are created.  . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.restore_image_task.create(
                ctx, bucket=value, object_key=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.restore_image_task.create bucket=value, object_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_restore_image_task",
        op_kwargs={
            "Bucket": bucket,
            "ObjectKey": object_key,
            "Name": name,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def add(hub, ctx, instance_profile_name: str, role_name: str) -> None:
    r"""
    **Autogenerated function**

    Adds the specified IAM role to the specified instance profile. An instance profile can contain only one role, and this quota cannot be increased. You can remove the existing role and then add a different role to an instance profile. You must then wait for the change to appear across all of Amazon Web Services because of eventual consistency. To force the change, you must disassociate the instance profile and then associate the instance profile, or you can stop your instance and then restart it.  The caller of this operation must be granted the PassRole permission on the IAM role by a permissions policy.  For more information about roles, see Working with roles. For more information about instance profiles, see About instance profiles.

    Args:
        instance_profile_name(str): The name of the instance profile to update. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        role_name(str): The name of the role to add. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.role.to_instance_profile.add(
                ctx, instance_profile_name=value, role_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.role.to_instance_profile.add instance_profile_name=value, role_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="add_role_to_instance_profile",
        op_kwargs={"InstanceProfileName": instance_profile_name, "RoleName": role_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Permanently deletes an IAM policy from the specified RuleGroup. The user making the request must be the owner of the RuleGroup.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the RuleGroup from which you want to delete the policy. The user making the request must be the owner of the RuleGroup.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.permission_policy.delete(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.permission_policy.delete resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="delete_permission_policy",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def get(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the IAM policy attached to the RuleGroup.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the RuleGroup for which you want to get the policy.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.permission_policy.get(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.permission_policy.get resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="get_permission_policy",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def put(hub, ctx, resource_arn: str, policy: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Attaches an IAM policy to the specified resource. The only supported use for this action is to share a RuleGroup across accounts. The PutPermissionPolicy is subject to the following restrictions:   You can attach only one policy with each PutPermissionPolicy request.   The policy must include an Effect, Action and Principal.     Effect must specify Allow.   The Action in the policy must be waf:UpdateWebACL, waf-regional:UpdateWebACL, waf:GetRuleGroup and waf-regional:GetRuleGroup . Any extra or wildcard actions in the policy will be rejected.   The policy cannot include a Resource parameter.   The ARN in the request must be a valid WAF RuleGroup ARN and the RuleGroup must exist in the same region.   The user making the request must be the owner of the RuleGroup.   Your policy must be composed using IAM Policy version 2012-10-17.   For more information, see IAM Policies.  An example of a valid policy parameter is shown in the Examples section below.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the RuleGroup to which you want to attach the policy.
        policy(str): The policy to attach to the specified RuleGroup.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.permission_policy.put(ctx, resource_arn=value, policy=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.permission_policy.put resource_arn=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="put_permission_policy",
        op_kwargs={"ResourceArn": resource_arn, "Policy": policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, cluster_arn: str = None) -> Dict:
    r"""
        **Autogenerated function**


        Gets the Apache Kafka versions to which you can update the MSK cluster.


        Args:
            cluster_arn(str, optional):
    The Amazon Resource Name (ARN) of the cluster check.
    . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.compatible_kafka_version.get_all(ctx)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.compatible_kafka_version.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="get_compatible_kafka_versions",
        op_kwargs={"ClusterArn": cluster_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, voice_connector_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the origination settings for the specified Amazon Chime Voice Connector.  If emergency calling is configured for the Amazon Chime Voice Connector, it must be deleted prior to deleting the origination settings.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.origination.delete(
                ctx, voice_connector_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.origination.delete voice_connector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_voice_connector_origination",
        op_kwargs={"VoiceConnectorId": voice_connector_id},
    )


async def get(hub, ctx, voice_connector_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves origination setting details for the specified Amazon Chime Voice Connector.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.origination.get(
                ctx, voice_connector_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.origination.get voice_connector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_voice_connector_origination",
        op_kwargs={"VoiceConnectorId": voice_connector_id},
    )


async def put(hub, ctx, voice_connector_id: str, origination: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Adds origination settings for the specified Amazon Chime Voice Connector.  If emergency calling is configured for the Amazon Chime Voice Connector, it must be deleted prior to turning off origination settings.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.
        origination(Dict): The origination setting details to add.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.origination.put(
                ctx, voice_connector_id=value, origination=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.origination.put voice_connector_id=value, origination=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="put_voice_connector_origination",
        op_kwargs={"VoiceConnectorId": voice_connector_id, "Origination": origination},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    capacity_reservation_id: str,
    next_token: str = None,
    max_results: int = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the resource groups to which a Capacity Reservation has been added.

    Args:
        capacity_reservation_id(str): The ID of the Capacity Reservation.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned nextToken value. This value can be between 5 and 500. If maxResults is given a larger value than 500, you receive an error. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.group_for_capacity_reservation.get(
                ctx, capacity_reservation_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.group_for_capacity_reservation.get capacity_reservation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_groups_for_capacity_reservation",
        op_kwargs={
            "CapacityReservationId": capacity_reservation_id,
            "NextToken": next_token,
            "MaxResults": max_results,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    stream_arn: str,
    shard_id: str,
    shard_iterator_type: str,
    sequence_number: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a shard iterator. A shard iterator provides information about how to retrieve the stream records from within a shard. Use the shard iterator in a subsequent GetRecords request to read the stream records from the shard.  A shard iterator expires 15 minutes after it is returned to the requester.

    Args:
        stream_arn(str): The Amazon Resource Name (ARN) for the stream.
        shard_id(str): The identifier of the shard. The iterator will be returned for this shard ID.
        shard_iterator_type(str): Determines how the shard iterator is used to start reading stream records from the shard:    AT_SEQUENCE_NUMBER - Start reading exactly from the position denoted by a specific sequence number.    AFTER_SEQUENCE_NUMBER - Start reading right after the position denoted by a specific sequence number.    TRIM_HORIZON - Start reading at the last (untrimmed) stream record, which is the oldest record in the shard. In DynamoDB Streams, there is a 24 hour limit on data retention. Stream records whose age exceeds this limit are subject to removal (trimming) from the stream.    LATEST - Start reading just after the most recent stream record in the shard, so that you always read the most recent data in the shard.  .
        sequence_number(str, optional): The sequence number of a stream record in the shard from which to start reading. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodbstream.shard_iterator.get(
                ctx, stream_arn=value, shard_id=value, shard_iterator_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodbstream.shard_iterator.get stream_arn=value, shard_id=value, shard_iterator_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodbstreams",
        operation="get_shard_iterator",
        op_kwargs={
            "StreamArn": stream_arn,
            "ShardId": shard_id,
            "ShardIteratorType": shard_iterator_type,
            "SequenceNumber": sequence_number,
        },
    )
